<?php

/**
 * This file is part of the Kolab Server Free/Busy Service
 *
 * @author Thomas Bruederli <bruederli@kolabsys.com>
 *
 * Copyright (C) 2013, Kolab Systems AG <contact@kolabsys.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

namespace Kolab\FreeBusy;

/**
 * Abstract class to fetch free/busy data from a specific source
 */
abstract class Source
{
	protected $config = array();

	/**
	 * Factory method creating an instace of Source according to config
	 *
	 * @param array Hash array with config
	 */
	public static function factory($url)
	{
		$config = parse_url($url);
		$config['url'] = $url;
		switch ($config['scheme']) {
			case 'file':	return new SourceFile($config);
			case 'imap':
			case 'imaps':	return new SourceIMAP($config);
			case 'http':
			case 'https':	return new SourceURL($config);
		}

		Logger::get('source')->addError("Invalid source configuration: " . $url);
		return null;
	}

	/**
	 * Default constructor
	 */
	public function __construct($config)
	{
		$this->config = $config;
	}

	/**
	 * Retrieve free/busy data for the given user
	 *
	 * @param array Hash array with user attributes
	 */
	abstract public function getFreeBusyData($user, $extended);

	/**
	 * Replace all %varname strings in config with values from $user
	 */
	protected function getUserConfig($user)
	{
		$config = array();
		foreach ($this->config as $k => $val) {
			if (is_string($val) && strpos($val, '%') !== false) {
				$val = preg_replace_callback(
					'/%\{?([a-z0-9]+)\}?/',
					function($m) use ($user) { return $user[$m[1]]; },
					$val);
			}

			$config[$k] = $val;
		}

		return $config;
	}
}